from setuptools import setup, find_packages

version = '1.0.1'

classifiers = """
Development Status :: 5 - Production/Stable
Intended Audience :: Developers
License :: OSI Approved :: MIT License
Operating System :: OS Independent
Programming Language :: Python :: 2.7
Programming Language :: Python :: 3.3
Programming Language :: Python :: 3.4
Programming Language :: Python :: 3.5
Programming Language :: Python :: 3.6
""".strip().splitlines()

long_description = (
    open('README.rst').read()
    + '\n' +
    open('CHANGES.rst').read()
    + '\n')

setup(
    name='calmjs.types',
    version=version,
    description="Types for the calmjs framework.",
    long_description=long_description,
    # Get more strings from
    # http://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=classifiers,
    keywords='',
    author='Tommy Yu',
    author_email='tommy.yu@auckland.ac.nz',
    url='https://github.com/calmjs/calmjs.types',
    license='mit',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    namespace_packages=['calmjs'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
    ],
    entry_points={
    },
    test_suite="calmjs.types.tests.make_suite",
)



# -*- coding: utf-8 -*-
"""
Various exceptions.
"""


class ValueSkip(ValueError):
    """Hint for marking certain values to be skiped."""


class RuntimeAbort(RuntimeError):
    """Base exception for known abort conditions."""


class ToolchainAbort(RuntimeAbort):
    """
    Events can raise this to abort a toolchain execution if a condition
    required this to be done.
    """


class ToolchainCancel(ToolchainAbort):
    """
    Events that interact with user input during a toolchain execution
    may raise this to signify user cancellation.
    """


class AdviceAbort(ToolchainAbort):
    """
    An advice step can raise this to signal an abort when it enters into
    a completely irrecoverable state or conditions, but not in an
    irrecoverable manner for the toolchain as a whole.
    """


class AdviceCancel(ToolchainCancel):
    """
    An advice step can raise this to simply cancel itself; toolchain
    execution should continue unimpeded.
    """
